Cricket Roadmap
===============

Cricket is a new project - we have lots of things that we'd like to do. If
you'd like to contribute, providing a patch for one of these features:

 * Use a standard protocol (e.g., subunit) for communicating between the
   executor and the GUI

 * Port to Python 3

 * Add a pytest backend

 * Add a nose backend

 * Add a selenium backend, including possibly adding the ability to collect
   and store screenshots at the end of each test

 * Improve GUI interface, including:

   - keyboard shortcuts

   - search

 * Integrate with coverage, and use tkreadonly to display coverage stats
   overlaid on actual code

 * Add historical tracking of test results

 * Integrate with testr

 * Add continuous background testing based on file modifications
